/*
 *  Object Name: S502 Unix device driver for the IMS B014.
 *  Revision   : 0.0
 *
 *  Copyright (c) Inmos Ltd, 1988.
 *  All rights reserved.
 *
 *  DESCRIPTION
 *     Header file for the S502 Unix device driver for the 
 *  IMS B014 VME board.
 *
 *  NOTES
 *
 *  HISTORY
 *     brwd 27-Jul-88 RJO - CREATION.
 *     brwd 24-Aug-88 RJO - Removed Ioctl stuff.
 *     brwc 05-Sep-88 RJO - Added C012ENABLE constants.
 *     brwc 07-Sep-88 RJO - Added C012DISABLE constants.
 *          04-Sep-90 BJ  - Changes for S514C
                          - got rid of a lot of unused stuff
 */


#define TRUE     1
#define FALSE    0

/*
 * Some useful typedefs.
 */
   
typedef unsigned char BYTE;
typedef unsigned char BOOL;


/*
 * Constants
 */

#define BIT_0            0x01
#define MAX_B014_BSIZE   4096

/*
 * Reset count constants.
 */

#define RESET_COUNT      1000

/*
 * Bit Mask Operations.
 */

#define ERRORBIT         0x01
#define TIMEOUTBIT       0x02

/*
 * IMS C012 Interrupt Mask Register Values.
 */


#define C012ENABLE       0x2   /* Enabling BIT_1 turns C012 interrupts on    */
#define C012DISABLE      ~C012ENABLE
/*
 * IMS B014 Interrupt Mask Register Values.
 */

#define B014INPUTINT      0x08  /* Enable INPUTINT interrupts  Recieve data  */
#define B014OUTPUTINT     0x04  /* Enable OUTPUTINT interrupts Send data     */
#define B014ERROR         0x02  /* Enable MERROR interrupts subsys error active  */
 
/*
 * IMS B014 Interface.
 */

struct B014Reg {
   BYTE Dummy0;          /* Location 0 not used                              */
   BYTE Idr;             /* Input data regsiter                              */
   BYTE Dummy1;          /* Location 2 not used                              */
   BYTE Odr;             /* Output data register                             */
   BYTE Dummy2;          /* Location 4 not used                              */
   BYTE Isr;             /* Input status register only lsb 2 bits used       */
   BYTE Dummy3;          /* Location 6 not used                              */
   BYTE Osr;             /* Output status register only lsb 2 bits used      */
   BYTE Dummy4;          /* Location 8 not used                              */
   BYTE ResetError;      /* Reset and error register only first lsb bit used */
   BYTE Dummy5;          /* Location 10 not used                             */
   BYTE Analyse;         /* Analyse register                                 */
   BYTE Dummy6;          /* Location 12 not used                             */
   BYTE IntMaskReg;      /* Interrupt mask register only 3 lsb bits used     */
   BYTE Dummy7;          /* Location 14 not used                             */
   BYTE IntLevelReg;     /* Interrupt level register                         */
   BYTE Dummy8;          /* Location 16 not used                             */
   BYTE IntStatusIDReg;  /* Interrupt status ID register                     */
   BYTE Dummy9;          /* Location 18 not used                             */
   BYTE TramError;       /* TRAM error register                              */
};
